# Changelog

## [0.2.0](https://github.com/jbussdieker/bussdcc-hardware/compare/v0.1.0...v0.2.0) (2026-03-03)


### Features

* **pump:** add Pump device support ([2858dfb](https://github.com/jbussdieker/bussdcc-hardware/commit/2858dfb41426a8ecdd1394a5b6b2924b797944ce))

## 0.1.0 (2026-03-02)


### Features

* **i2c:** add I2CBus and NAU7802 device support ([12c78df](https://github.com/jbussdieker/bussdcc-hardware/commit/12c78dfcf0d715f4c2cc5aee57e03df285483f5a))
* initial commit ([01b3136](https://github.com/jbussdieker/bussdcc-hardware/commit/01b313647497bffa5c14babe7bb0801c9d082cf0))


### Documentation

* **readme:** expand README with project concepts ([ee73fc1](https://github.com/jbussdieker/bussdcc-hardware/commit/ee73fc17cbfd46a17021e3678108df9681922541))
